# Changelog

1.0.0 (06-12-2022)
------------------
+ updated documentation, renamed package
+ updated all modules
+ setup automated workflows

0.2.0 (31-08-2022)
------------------
+ added `power` module to fetch surface temperature data directly from 
NASA POWER (Prediction of Worldwide Energy Resources).

0.1.0 (20-08-2022)
------------------
+ added `airs` module to fetch surface and atmospheric data directly from AIRS
aboard NASA's Aqua Satellite.
+ finished updating all functions to `airs` module.

0.0.1 (14-08-2022)
------------------
+ created the package.
+ creating setup files.
